@@ -13,6 +13,7 @@
 #include "log.h"
 #include "shell.h"
 #include "phosh-wayland.h"
+#include "wall-clock.h"
 #include "background-cache.h"
 
 #include <handy.h>
@@ -98,6 +99,7 @@ int main(int argc, char *argv[])
   g_autoptr(PhoshShell) shell = NULL;
   g_autoptr (PhoshBackgroundCache) background_cache = NULL;
   g_autoptr (GTimer) timer = g_timer_new ();
+  g_autoptr (PhoshWallClock) wall_clock = phosh_wall_clock_new ();
 
   const GOptionEntry options [] = {
     {"unlocked", 'U', 0, G_OPTION_ARG_NONE, &unlocked,
@@ -135,6 +137,7 @@ int main(int argc, char *argv[])
   g_unix_signal_add (SIGINT, on_shutdown_signal, NULL);
   g_unix_signal_add (SIGUSR1, on_sigusr1_signal, NULL);
 
+  phosh_wall_clock_set_default (wall_clock);
   wl = phosh_wayland_get_default ();
   background_cache = phosh_background_cache_get_default ();
   shell = phosh_shell_get_default ();
