@@ -9,6 +9,7 @@
 #pragma once
 
 #include "launcher-entry-manager.h"
+#include "monitor-manager.h"
 #include "session-manager.h"
 
 G_BEGIN_DECLS
@@ -17,10 +18,11 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (PhoshShell, phosh_shell, PHOSH, SHELL, GObject)
 
-PhoshShell             *phosh_shell_get_default (void);
+PhoshShell                *phosh_shell_get_default (void);
 
 /* Created by the shell on startup */
 PhoshLauncherEntryManager *phosh_shell_get_launcher_entry_manager (PhoshShell *self);
+PhoshMonitorManager       *phosh_shell_get_monitor_manager (PhoshShell *self);
 PhoshSessionManager       *phosh_shell_get_session_manager (PhoshShell *self);
 
 
